@@ -3,19 +3,15 @@
 """This is a helper module to encapsulate the functionality that represents
 Splunk's alert action feature.
 """
-
-# Python Standard Libraries
 import os
 
-# py 2/3 compatible
+import splunk_appinspect
+
 try:
     import itertools.ifilter as filter
 except ImportError:
     pass
 
-# Custom
-import splunk_appinspect
-
 
 class AlertActions(object):
     def __init__(self, app):
@@ -210,9 +206,7 @@ class AlertActions(object):
                             os.path.join(self.app.app_dir, directory, filename)
                         )
                         resource.ext = ext
-                        resource.app_file_path = os.path.join(
-                            directory, filename
-                        )
+                        resource.app_file_path = os.path.join(directory, filename)
                         resource.tags.append(arch)
 
                         if ext in self.WINDOWS_EXES:
@@ -243,7 +237,7 @@ class AlertAction(object):
         workflow_html_path="",
         relative_icon_path="",
         relative_workflow_html_path="",
-        python_version=""
+        python_version="",
     ):
         self.name = section.name
         self.lineno = section.lineno
