@@ -969,6 +969,30 @@ class App(object):
     def get_custom_commands(self):
         return custom_commands.CustomCommands(self)
 
+    def get_custom_executable_files(self, local=None):
+        executable_files = []
+        custom_commands = self.get_custom_commands()
+        for command in custom_commands.get_commands():
+            # If set to "true", specifies that the command should be run on the search head only.
+            if local is False and command.local:
+                continue
+            elif local is True and not command.local:
+                continue
+            for execute_file in command.executable_files:
+                if execute_file.is_path_pointer:
+                    executable_files.extend(
+                        custom_commands.find_pointer_scripts(execute_file)
+                    )
+                else:
+                    executable_files.append(execute_file.relative_path)
+        return executable_files
+
+    def get_non_distributed_files(self):
+        return self.distsearch_conf().get_replication_blacklist_files()
+
+    def get_transforms_executable_files(self):
+        return self.transforms_conf().get_external_executable_file_path_list()
+
     def get_custom_visualizations(self):
         return custom_visualizations.CustomVisualizations(self)
 
@@ -1012,7 +1036,7 @@ class App(object):
         return self.get_config(
             "distsearch.conf",
             dir=dir,
-            config_file=distsearch_configuration_file.DistsearchConfigurationFile(),
+            config_file=distsearch_configuration_file.DistsearchConfigurationFile(self),
         )
 
     def indexes_conf(self, dir="default"):
@@ -1047,7 +1071,7 @@ class App(object):
         return self.get_config(
             "transforms.conf",
             dir=dir,
-            config_file=transforms_configuration_file.TransformsConfigurationFile(),
+            config_file=transforms_configuration_file.TransformsConfigurationFile(self),
         )
 
     def web_conf(self, dir="default"):
