@@ -1,6 +1,7 @@
 """Splunk app image file abstraction resource module"""
 
 from PIL import Image
+
 from .file_resource import FileResource
 
 
@@ -8,8 +9,7 @@ class ImageResource(FileResource):
     """store metadata of an image file in app"""
 
     def __init__(self, image_path):
-        """This only supports PNG/JPEG/GIF image formats, and will thrown NotImplementedError for non supported formats
-        """
+        """This only supports PNG/JPEG/GIF image formats, and will thrown NotImplementedError for non supported formats"""
         FileResource.__init__(self, image_path)
         self.image_path = image_path
         self.meta = Image.open(self.image_path)
