@@ -2,8 +2,12 @@
 Execute xml minidom commands
 """
 
-from splunk_appinspect.python_modules_metadata.metadata_common.metadata_consts import TagConsts
-from splunk_appinspect.python_modules_metadata.metadata_common.metadata_decorator import tags
+from splunk_appinspect.python_modules_metadata.metadata_common.metadata_consts import (
+    TagConsts,
+)
+from splunk_appinspect.python_modules_metadata.metadata_common.metadata_decorator import (
+    tags,
+)
 
 
 @tags(TagConsts.FILE_READ_AND_WRITE)
@@ -18,9 +22,10 @@ class Document:
     """
     xml.dom.minidom.Document commands
     """
+
     @tags(TagConsts.FILE_READ_AND_WRITE)
     def writexml(self):
         """
         Write to file or sys.stdout and so on
         """
-        pass
\ No newline at end of file
+        pass
